@@ -354,7 +354,8 @@ class Neural(BaseMixer):
             ydf = pd.DataFrame({'prediction': decoded_predictions})
 
             if args.predict_proba and self.supports_proba:
-                raw_predictions = np.array(all_probs).squeeze()
+                raw_predictions = np.array(all_probs).squeeze(axis=1)
+
                 for idx, label in enumerate(rev_map.values()):
                     ydf[f'__mdb_proba_{label}'] = raw_predictions[:, idx]
 
